
import datetime
import uuid

from nsj_rest_lib.decorator.dto import DTO
from nsj_rest_lib.descriptor.dto_field import DTOField
from nsj_rest_lib.descriptor.dto_field_validators import DTOFieldValidators
from nsj_rest_lib.dto.dto_base import DTOBase



# Configuracoes execucao
from nsj_integracao_api_entidades.config import (tenant_is_partition_data)

@DTO()
class ContratoDTO(DTOBase):
    # Atributos da entidade
    id: uuid.UUID = DTOField(
      pk=True,
      entity_field='contrato',
      resume=True,
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tenant: int = DTOField(
      partition_data=tenant_is_partition_data,
      resume=True,
      not_null=True,)
    codigo: str = DTOField(
      candidate_key=True,
      strip=False,
      resume=True,
      not_null=True,)
    descricao: str = DTOField(
      not_null=True,)
    tipocontrato: int = DTOField(
      not_null=True,)
    definicaocontratante: str = DTOField(
      not_null=True,)
    definicaobeneficiario: str = DTOField(
      not_null=True,)
    datainicial: datetime.datetime = DTOField(
      not_null=True,)
    administradorlegal: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    estabelecimento: uuid.UUID = DTOField(
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    participante: uuid.UUID = DTOField(
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    fiador: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    conta: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    bempatrimonial: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    qtddiasdesconto: int = DTOField(
      not_null=True,)
    qtddiasmulta: int = DTOField(
      not_null=True,)
    qtddiasjurosdiarios: int = DTOField(
      not_null=True,)
    percentualcomissao: float = DTOField(
      not_null=True,)
    valorcomissao: float = DTOField(
      not_null=True,)
    percentualretencaoimposto: float = DTOField(
      not_null=True,)
    valorretencaoimposto: float = DTOField(
      not_null=True,)
    familia: uuid.UUID = DTOField(
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    processado: int = DTOField(
      not_null=True,)
    cancelado: bool = DTOField(
      not_null=True,)
    datahoracancelamento: datetime.datetime = DTOField()
    origem: int = DTOField(
      not_null=True,)
    emitirnotafiscal: bool = DTOField(
      not_null=True,)
    tipocontabilizacao: int = DTOField(
      not_null=True,)
    formula_id: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    lastupdate: datetime.datetime = DTOField()
    unidadenatureza: int = DTOField(
      not_null=True,)
    unidadeintervalonatureza: int = DTOField(
      not_null=True,)
    quantidadeintervalonatureza: int = DTOField(
      not_null=True,)
    tipovencimento: int = DTOField(
      not_null=True,)
    diavencimento: int = DTOField(
      not_null=True,)
    adicaomesesvencimento: int = DTOField(
      not_null=True,)
    tipocobranca: int = DTOField(
      not_null=True,)
    qtddiasparainicio: int = DTOField(
      not_null=True,)
    qtddiasparafim: int = DTOField(
      not_null=True,)
    qtdmesesparareajuste: int = DTOField(
      not_null=True,)
    percentualdesconto: float = DTOField(
      not_null=True,)
    percentualmulta: float = DTOField(
      not_null=True,)
    percentualjurosdiarios: float = DTOField(
      not_null=True,)
    indice: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    dataproximoreajuste: datetime.datetime = DTOField()
    considerardatainicio: bool = DTOField(
      not_null=True,)
    parcelainicial: int = DTOField(
      not_null=True,)
    parcelafinal: int = DTOField(
      not_null=True,)
    parcelaatual: int = DTOField(
      not_null=True,)
    participantecomissao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    numero: int = DTOField(
      not_null=True,)
    processaperiodoanterior: bool = DTOField(
      not_null=True,)
    debitoautomatico: bool = DTOField(
      not_null=True,)
    perfilcontrato: str = DTOField(
      not_null=True,
      default_value='S',)
    classfinanceiracomissao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tipoemissao: int = DTOField(
      not_null=True,)
    qtddiasemissaotitulo: int = DTOField(
      not_null=True,)
    id_tipo_outras_recdesp: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    gerartitulos: bool = DTOField(
      not_null=True,)
    diaparafaturamento: int = DTOField(
      not_null=True,)
    id_formapagamento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    diainicioreferencia: int = DTOField()
    encerramentoprevisaofinanceira: int = DTOField(
      not_null=True,)
    datahoraencerramento: datetime.datetime = DTOField()
    pessoamunicipio: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_documento_vinculado: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    observacao: str = DTOField()
    templateordemservico: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    grupofaturamento: int = DTOField(
      not_null=True,)
    datacontrolesistema: datetime.datetime = DTOField(
      not_null=True,)
    previsaofinanceirapersona: bool = DTOField(
      not_null=True,)
    tipoordempagamentopersona: int = DTOField(
      not_null=True,
      default_value=-1,)
    reajusteautomatico: bool = DTOField(
      not_null=True,)
    id_proposta: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    created_at: datetime.datetime = DTOField()
    created_by: dict = DTOField()
    anteciparvencimentodiautil: bool = DTOField()
    contratoemrenegociacao: bool = DTOField(
      not_null=True,)
    layoutcobranca: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    detentor_id: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    titulosprovisorios: bool = DTOField()
    usarindicevariavel: bool = DTOField(
      not_null=True,)
    pisretido: float = DTOField()
    cofinsretido: float = DTOField()
    csllretido: float = DTOField()
    irretido: float = DTOField()
    issretido: float = DTOField()
    inssretido: float = DTOField()
    outrasretencoes: float = DTOField()
    descricaooutrasretencoes: str = DTOField(
      default_value='',)
    id_tipo_outras_recdesplocacao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    contabilizar: bool = DTOField()
    contabilizar_baixa: bool = DTOField()
    projeto: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    competencia_vencimento: bool = DTOField()
    observacao_titulo: str = DTOField()
    template_observacao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    numerorps: int = DTOField()
    descontoglobalitensnaofaturados: float = DTOField()

